#
# spec file for package gpu-screen-recorder-gtk
#
# Copyright (c) 2024 mantarimay
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%bcond_with test
%define appid   com.dec05eba.gpu_screen_recorder
Name:           gpu-screen-recorder-gtk
Version:        20241121
Release:        1.1
Summary:        GTK frontend for GPU Screen Recorder
License:        GPL-3.0-only
URL:            https://git.dec05eba.com/gpu-screen-recorder-gtk/about
Source:         %{name}-%{version}.tar.zst
BuildRequires:  cmake
BuildRequires:  gcc-c++
BuildRequires:  gtk3-devel
BuildRequires:  desktop-file-utils
BuildRequires:  fdupes
BuildRequires:  libayatana-appindicator3-devel
BuildRequires:  meson
BuildRequires:  zstd
Requires:       gpu-screen-recorder

%description
This is a screen recorder that has minimal impact on system performance
by recording your monitor using the GPU only, similar to shadowplay on
windows. This is the fastest screen recording tool for Linux.

This screen recorder can be used for recording your desktop offline, for
live streaming and for nvidia shadowplay-like instant replay, where only
the last few minutes are saved.

GTK frontend for GPU Screen Recorder.

%prep
%autosetup

%build
%meson
%meson_build

%install
%meson_install

%fdupes %{buildroot}%{_datadir}/icons

%if %{with test}
%check
%meson_test
%endif

%files
%license LICENSE
%doc README.md
%{_bindir}/%{name}
%{_datadir}/icons/hicolor/*/*/%{appid}*.png
%{_datadir}/applications/%{appid}.desktop
%{_datadir}/metainfo/%{appid}.appdata.xml

%changelog
* Thu Nov 21 2024 mantarimay@pm.me
- Update to version 20241121:
  * Merge audio devices and application audio into one list
  * Always show record buttons
  * Better scrolled window resizing
* Sat Nov 16 2024 mantarimay@pm.me
- Update to version 20241116:
  * Add support application audio recording
* Tue Nov  5 2024 mantarimay@pm.me
- Update to version 20241105:
  * default 15000kbps
  * Change default bitrate
  * Better error messages, always force urgent notification on kde,
    recommend constant bitrate for replay
  * Add video resolution option
* Tue Oct 22 2024 mantarimay@pm.me
- Update to version 20241022:
  * Properly fallback to software encoding
* Sat Oct 12 2024 mantarimay@pm.me
- Update to version 20241012:
  * Constant bitrate is recommended for live streaming
  * Change default bitrate quality
  * Use -q instead of -bitrate for constant bitrate quality
* Mon Sep 23 2024 mantarimay@pm.me
- Update to version 20240921:
  * Show warning when selecting hevc/av1 on amd because of amd
    driver/ffmpeg bug
* Tue Sep 17 2024 mantarimay@pm.me
- Update to version 20240917:
  * only bump version to 4.1.8
* Tue Sep 10 2024 mantarimay@pm.me
- Update to version 20240906:
  * Fix Documentation
* Sat Aug 31 2024 mantarimay@pm.me
- Update to version 20240831:
  * Add version to title
* Tue Aug 20 2024 mantarimay@pm.me
- Update to version 20240820:
  * Fix audio devices with space in id not working, add 10 bit
    option for hevc and av1
  * Clearify that it works on amd, intel and nvidia
  * Fix possible capture lag (especially with desktop portal
    capture)
* Mon Aug 19 2024 Muhammad Akbar Yanuar Mantari <mantarimay@pm.me>
- Initial package
